@@ -48,7 +48,7 @@ class ConfigTypes(Enum):
     PAYMENT_EXCEL_FILE = auto()
     PAYMENT_GOOGLE_SHEET_ID = auto()
     PAYMENT_GOOGLE_CRED = auto()
-    PAYMENT_GOOGLE_PICKLE = auto()
+    PAYMENT_GOOGLE_CRED_PATH = auto()
     PAYMENT_EMAIL_COL = auto()
     PAYMENT_USERNAME_COL = auto()
     PAYMENT_EXPIRATION_COL = auto()
