@@ -87,9 +87,9 @@ class PaymentsExcelLoader(PaymentsLoaderBase):
         payments_data_err = PaymentsDataErrors()
 
         # Get column indexes
-        email_col_idx = self.config.GetValue(ConfigTypes.PAYMENT_EMAIL_COL)
-        username_col_idx = self.config.GetValue(ConfigTypes.PAYMENT_USERNAME_COL)
-        expiration_col_idx = self.config.GetValue(ConfigTypes.PAYMENT_EXPIRATION_COL)
+        email_col_idx = self._ColumnToIndex(self.config.GetValue(ConfigTypes.PAYMENT_EMAIL_COL))
+        username_col_idx = self._ColumnToIndex(self.config.GetValue(ConfigTypes.PAYMENT_USERNAME_COL))
+        expiration_col_idx = self._ColumnToIndex(self.config.GetValue(ConfigTypes.PAYMENT_EXPIRATION_COL))
 
         # Read each row
         for i in range(sheet.nrows):
